@@ -7,7 +7,7 @@ Usage::
     import boto3
 
     from mypy_boto3_transfer import TransferClient
-    from mypy_boto3_transfer import (
+    from mypy_boto3_transfer.paginator import (
         ListServersPaginator,
     )
 
@@ -27,12 +27,12 @@ __all__ = ("ListServersPaginator",)
 
 class ListServersPaginator(Boto3Paginator):
     """
-    [Paginator.ListServers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/transfer.html#Transfer.Paginator.ListServers)
+    [Paginator.ListServers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/transfer.html#Transfer.Paginator.ListServers)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListServersResponseTypeDef]:
         """
-        [ListServers.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/transfer.html#Transfer.Paginator.ListServers.paginate)
+        [ListServers.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/transfer.html#Transfer.Paginator.ListServers.paginate)
         """
